@@ -3,4 +3,4 @@ void R_read_mc(char **group, int *ix, char **mc_file, int *iter_b,
 void read_mc
    (char* group, int ix, char *mc_file, int iter_b, int forward, int n,
     double out[]);
-void display_mc(char** mc_files,int out[5]);
+void summary_mc(char** mc_files,int out[5]);
